==> substance_5.0.orig.tar.gz: substance-5.0.orig/src/org/jvnet/substance/api/tabbed/VetoableMultipleTabCloseListener.java <==
/*
 * Copyright (c) 2005-2008 Substance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package org.jvnet.substance.api.tabbed;

import java.awt.Component;
import java.util.Set;

import javax.swing.JTabbedPane;

/**
 * Vetoable listener on tabs closing. This class is part of officially supported
 * API.
 * 
 * @author Kirill Grouchnikov
 */
public interface VetoableMultipleTabCloseListener extends
		MultipleTabCloseListener {
	/**
	 * Called when tabs are about to be closed. Can veto the tabs closing.
	 * 
	 * @param tabbedPane
	 *            Tabbed pane.
	 * @param tabComponents
	 *            Tab components to be closed.
	 * @return <code>true</code> if the corresponding tabs shouldn't be
	 *         closed, <code>false</code> otherwise.
	 */
	public boolean vetoTabsClosing(JTabbedPane tabbedPane,
			Set<Component> tabComponents);
}

==> substance_5.3.orig.tar.gz: substance-5.3.orig/src/org/jvnet/substance/api/tabbed/VetoableMultipleTabCloseListener.java <==
/*
 * Copyright (c) 2005-2009 Substance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package org.jvnet.substance.api.tabbed;

import java.awt.Component;
import java.util.Set;

import javax.swing.JTabbedPane;

/**
 * Vetoable listener on tabs closing. This class is part of officially supported
 * API.
 * 
 * @author Kirill Grouchnikov
 */
public interface VetoableMultipleTabCloseListener extends
		MultipleTabCloseListener {
	/**
	 * Called when tabs are about to be closed. Can veto the tabs closing.
	 * 
	 * @param tabbedPane
	 *            Tabbed pane.
	 * @param tabComponents
	 *            Tab components to be closed.
	 * @return <code>true</code> if the corresponding tabs shouldn't be closed,
	 *         <code>false</code> otherwise.
	 */
	public boolean vetoTabsClosing(JTabbedPane tabbedPane,
			Set<Component> tabComponents);
}
